==> phplist-2.10.17.zip: phplist-2.10.17/public_html/lists/admin/lan/nl/members.php <==
<?php
$lan = array(
  'You do not have enough priviliges to view this page' => 'Je hebt niet genoeg toegangsrechten om deze pagina te bekijken',
  'Add a user' => 'Voeg een gebruiker toe',
  'add user' => 'Voeg Een Gebruiker Toe',
  'Members of' => 'Lid van',
  'Tag all users in this page' => 'Markeer alle gebruikers op deze pagina',
  'back to this list' => 'terug naar deze lijst',
  'Download users on this list as a CSV file' => 'Download gebruikers in deze lijst als een CSV bestand',
  'Please enter a listid' => 'Voeg aub een lijst-id in',
  'Processing' => 'Verwerken',
  'users were moved to' => 'Gebruikers zijn verplaatst naar',
  'users were copied to' => 'Gebruikers zijn gekopieerd naar',
  'users were deleted from this list' => 'Gebruikers zijn verwijdert van deze lijst',
  'Users found, click add to add this user' => 'Gebruikers gevonden, klik Toevoegen om deze gebruiker toe te voegen',
  'Add' => 'Toevoegen',
  'No user found with that email' => 'Geen gebruiker met dat email adres gevonden',
  'Inserting user' => 'Gebruiker invoegen',
  'User added' => 'Gebruiker toegevoegd',
  'Deleting' => 'Verwijderen',
  'Done' => 'Klaar',
  'Users on this list' => 'Gebruikers in deze lijst',
  'Listing user' => 'Lijst van gebruikers',
  'to' => 'tot',//in sentence 'listing user 1  to  50'
  'Listing user 1 to 50' => 'Lijst van gebruikers 1 tot 50',
  'Members' => 'Leden',
  'confirmed' => 'Bevestigd',
  'tag' => 'markeer',
  'del' => 'wis',
  'Delete'=>'Verwijder',
  '# msgs' => '# ber',
  '# rss' => '# rss',
  'rss freq' => 'rss freq',
  'last sent' => 'laatst verzonden',
  'What to do with "Tagged" users' => 'Wat te doen met &acute;Gemarkeerde&acute; gebruikers',
  'This will only process the users in this page that have the "Tag" checkbox checked' => 'Dit zal enkel de gebruikers op deze pagina die de &acute;Markeer&acute; checkbox aangevinkt hebben verwerken',
  'delete' => 'Verwijder',
  'move' => 'Verplaats',
  'copy' => 'Kopieer',
  'nothing' => 'Niets',
  'to' => 'tot', # as in destination
  'from this list' => 'van deze lijst',
  'What to do with all users' => 'Wat te doen met alle gebruikers',
  'This will process all users on this list' => 'Dit zal alle gebruikers op deze lijst verwerken',
  'do it' => 'doe het',


);
?>

==> phplist-3.0.5.zip: phplist-3.0.5/public_html/lists/admin/lan/nl/members.php <==
<?php
$lan = array(
  'You do not have enough priviliges to view this page' => 'Je hebt niet genoeg toegangsrechten om deze pagina te bekijken',
  'Add a user' => 'Voeg een gebruiker toe',
  'add user' => 'Voeg Een Gebruiker Toe',
  'Members of' => 'Lid van',
  'Tag all users in this page' => 'Markeer alle gebruikers op deze pagina',
  'back to this list' => 'terug naar deze lijst',
  'Download users on this list as a CSV file' => 'Download gebruikers in deze lijst als een CSV bestand',
  'Please enter a listid' => 'Voeg aub een lijst-id in',
  'Processing' => 'Verwerken',
  'users were moved to' => 'Gebruikers zijn verplaatst naar',
  'users were copied to' => 'Gebruikers zijn gekopieerd naar',
  'users were deleted from this list' => 'Gebruikers zijn verwijdert van deze lijst',
  'Users found, click add to add this user' => 'Gebruikers gevonden, klik Toevoegen om deze gebruiker toe te voegen',
  'Add' => 'Toevoegen',
  'No user found with that email' => 'Geen gebruiker met dat email adres gevonden',
  'Inserting user' => 'Gebruiker invoegen',
  'User added' => 'Gebruiker toegevoegd',
  'Deleting' => 'Verwijderen',
  'Done' => 'Klaar',
  'Users on this list' => 'Gebruikers in deze lijst',
  'Listing user' => 'Lijst van gebruikers',
  'to' => 'tot',//in sentence 'listing user 1  to  50'
  'Listing user 1 to 50' => 'Lijst van gebruikers 1 tot 50',
  'Members' => 'Leden',
  'confirmed' => 'Bevestigd',
  'tag' => 'markeer',
  'del' => 'wis',
  'Delete'=>'Verwijder',
  '# msgs' => '# ber',
  '# rss' => '# rss',
  'rss freq' => 'rss freq',
  'last sent' => 'laatst verzonden',
  'What to do with "Tagged" users' => 'Wat te doen met &acute;Gemarkeerde&acute; gebruikers',
  'This will only process the users in this page that have the "Tag" checkbox checked' => 'Dit zal enkel de gebruikers op deze pagina die de &acute;Markeer&acute; checkbox aangevinkt hebben verwerken',
  'delete' => 'Verwijder',
  'Move' => 'Verplaats',
  'Copy' => 'Kopieer',
  'Nothing' => 'Niets',
  'to' => 'tot', # as in destination
  'from this list' => 'van deze lijst',
  'What to do with all users' => 'Wat te doen met alle gebruikers',
  'This will process all users on this list' => 'Dit zal alle gebruikers op deze lijst verwerken',
  'do it' => 'doe het',


);
?>
